@@ -337,7 +337,7 @@ class GCP:
 
     @staticmethod
     def execute_sql_statement(
-        sql_statement: str, table_id: str, query_parameters: list = None
+        sql_statement: str, table_id: str, job_type: str, query_parameters: list = None
     ):
         """
         Executes a general SQL statement in BigQuery.
@@ -346,6 +346,7 @@ class GCP:
         ----------
         sql_statement: str, the SQL statement to be executed.
         table_id: str, the table name to be processed.
+        job_type: str, the type of job to be performed, eg 'delete' or 'insert'.
         query_parameters: list, the list of parameters to be considered when processing the job.
 
         Returns
@@ -362,9 +363,7 @@ class GCP:
 
         query_job = client.query(sql_statement, job_config=job_config)
 
-        print(
-            "BigQuery (delete_from_bigquery): Starting job {}".format(query_job.job_id)
-        )
+        print(f"BigQuery ({job_type}_from_bigquery): Starting job {query_job.job_id}")
         query_job.result()  # awaits result of job
 
         ## get total number of rows after
@@ -372,9 +371,7 @@ class GCP:
         number_of_rows_after = destination_table.num_rows
 
         print(
-            "BigQuery (delete_from_bigquery): Job finished. Deleted {} rows.".format(
-                -1 * (number_of_rows_after - number_of_rows_before)
-            )
+            f"BigQuery ({job_type}_from_bigquery): Job finished. {General.past_tense(job_type).title()} {-1 * (number_of_rows_after - number_of_rows_before)} rows."
         )
 
 
@@ -565,3 +562,26 @@ class General:
         with smtplib.SMTP_SSL(smtp_server, port, context=context) as server:
             server.login(sender_email, password)
             server.sendmail(sender_email, receiver_email, message)
+
+    @staticmethod
+    def past_tense(word: str) -> str:
+        """
+        Converts a word to its past tense equivalent.
+
+        Parameters
+        ----------
+        word: str, the string input.
+
+        Returns
+        -------
+        The past tense of the word, also a str.
+
+        """
+        T, x, m = "aeiou", "ed", word[-1]
+        return [
+            [
+                [word + x, word + m + x][word[-2] in T and m and word[-3] not in T],
+                [word + x, word[:-1] + "ied"][word[-2] not in T],
+            ][m == "y"],
+            word + "d",
+        ][m == "e"]
